#!/bin/bash
#
# author           : George Vlahavas (vlahavas~AT~gmail~DOT~com, gapan@zenwalk forums)
# project web page : http://clay.ll.pl/lss/
# source           : http://clay.ll.pl/lss/lss-0.1.6.tar.gz

# Package name
NAME="lss"
# Package version
VERSION="0.1.6"
# Source code URL
SOURCE="http://clay.ll.pl/lss/lss-$VERSION.tar.gz"
# Files that should be placed in /usr/doc/package-version/
DOCS="AUTHORS COPYING ChangeLog README THANKS"
# ./configure options
CONFIGOPTIONS="--prefix=/usr"

CWD=`pwd`
PKG="$CWD/$NAME-install"
ARCH="i486"
CPU="i686"
BUILD="52.1"

rm -rf $PKG
mkdir -p $PKG

# Create package install directory
mkdir $PKG/install

# Create the slack-desc file
cat > $PKG/install/slack-desc << END
$NAME: lss - LaTeX Symbols Selector
$NAME:
$NAME: LSS is a symbol browser to help creating LaTeX documents with
$NAME: many math symbols.
$NAME:
$NAME:
$NAME:
$NAME:
$NAME:
$NAME:
$NAME:
END

# Check to see if source is present. If it's not, download it
rm -rf $NAME-$VERSION
if [ -f $NAME-$VERSION.tar.gz ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c $SOURCE
fi

# Unpack source
tar xvzf $NAME-$VERSION.tar.gz

#
# building-computer dependent: the number of parallel 'jobs' of 'make'
#
# 'heavy' computer: 6 build-jobs at once
#
#numjobs='-j6'
#
# 'light' computer: 2 build-jobs at once
#
numjobs='-j2'

# Configure and make
cd $NAME-$VERSION
export CFLAGS="-O2 -march=$ARCH -mtune=$CPU"
export CXXFLAGS="-O2 -march=$ARCH -mtune=$CPU"
./configure $CONFIGOPTIONS
sed -i -e 's,CFLAGS = ,CFLAGS = -O2 -march=i486 -mtune=i686 ,' Makefile
sed -i -e 's,CPPFLAGS = ,CPPFLAGS = -O2 -march=i486 -mtune=i686 ,' Makefile
sed -i -e 's,CFLAGS = ,CFLAGS = -O2 -march=i486 -mtune=i686 ,' src/Makefile
sed -i -e 's,CPPFLAGS = ,CPPFLAGS = -O2 -march=i486 -mtune=i686 ,' src/Makefile
make $numjobs

# Install on temporary directory
make install DESTDIR=$PKG

# Fix name in desktop entry
sed -i -e "s/Name=Lss/Name=LaTex Symbol Selector/" $PKG/usr/share/applications/lss.desktop

# Strip binaries
cd $PKG
find . | xargs file | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

# Copy Docs
mkdir -p $PKG/usr/doc/$NAME-$VERSION
cd $CWD/$NAME-$VERSION
cp -a $DOCS $PKG/usr/doc/$NAME-$VERSION

# Move the icons to the right place
mkdir -p $PKG/usr/share/icons/hicolor/scalable/apps
mv $PKG/usr/share/pixmaps/lss.svg $PKG/usr/share/icons/hicolor/scalable/apps
mkdir -p $PKG/usr/share/icons/hicolor/48x48/apps
mv $PKG/usr/share/pixmaps/lss.svg $PKG/usr/share/icons/hicolor/48x48/apps
rm -rf $PKG/usr/share/pixmaps

# Add the build-file in the package
mkdir -p $PKG/usr/src/$NAME-$VERSION
cp "$CWD/build-$NAME.sh" "$PKG/usr/src/$NAME-$VERSION/build-$NAME.sh"
chmod a+x "$PKG/usr/src/$NAME-$VERSION/build-$NAME.sh"

# Make sure ownerships and permissions are sane
cd $PKG
chown -R root:root .
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# Make the package
makepkg -l y -c n $CWD/$NAME-$VERSION-$ARCH-$BUILD.tgz

# Calculate md5sum
cd $CWD/
md5sum $NAME-$VERSION-$ARCH-$BUILD.tgz > $NAME-$VERSION-$ARCH-$BUILD.md5

# Remove source-code and temporary install directories
# since they are not needed anymore
rm -rf $CWD/$NAME-$VERSION
rm -rf $PKG
